function [cal]=CalibrateADXL(ch,sourcefile)

if nargin<2; sourcefile=0; end
if nargin<1; ch=2:5;       end

%--- Read and interpret measurement file ---
[sample,wfm,par]=InterpretTRC(sourcefile);
scaled= MHscaleData(sample,wfm,[1 0]);
t  = scaled.t;
v  = scaled.v(:,ch);
fs = wfm.samplerate;

%[Np Nw] = size(wfm.v);
[Nt Nv]= size(v);

Vdd  = mean(scaled.v(:,1));
dVdd = std(scaled.v(:,1));

%--- Filter traces, find voltage differences ---
fc = 1;    % Hz   LP cut-off frequency
[b,a]=butter(2,fc/(fs/2));
vf= filtfilt(b,a,v);

vs= sort(vf);
vmin= mean(vs(1:5      ,:));
vmax= mean(vs(end-5:end,:));

dv= vmax-vmin;             % V    Voltage difference, +-g
v0= mean([vmax;vmin]);     % V    Offset, voltage at 0 g
r0= v0/Vdd;                % rel  Offset, relative Vdd
S = dv/2;                  % V/g  Sensitivity
Sr= S/Vdd;                 % 1/g  Sensitivity rel. Vdd

%--- Store in structure ---
cal.vmax= vmax;
cal.vmin= vmin;
cal.dv = dv;
cal.v0 = v0;
cal.r0 = r0;
cal.S  = S;
cal.Sr = Sr;

%--- Plot curves ---
plot (t, v, 'b-', t, vf, 'r-' );
hold on;

ax=axis;
plot (ax(1:2), repmat(vmin,2,1), 'c-' );
plot (ax(1:2), repmat(vmax,2,1), 'c-' );
%plot (ax(1:2), repmat(v0,  2,1), 'k-' );

hold off;
xlabel('Time [s]');
ylabel('Voltage [V]');
grid on;

return