function GraphOnOff(figno,axtag,linetag,n,on)
% function GraphOnOff(figno,axtag,linetag,on)
%
% Turn graph on or off
%
% figno   : No. of figure containig graph
% axtag   : Tag of axis containing graph, i.e. subplot
% linetag : Tag of 'line', i.e. graph to be switched on/off
% n       : Number of graph, when several graphs have identical tags, e.g.
%          created with same 'plot' command
% on      : On (1) or off (0)
%
% The function requires that both the 'axis' (subplot) and the 'line'
% (graph) are marked with a 'Tag'. This is done using the 'Tag' properties
% of the 'axes' and 'plot' commands
% 

% Lars Hoff, HVE, Feb 2007


if any(findobj(0) == figno)                           % Check that figure exists
    figchild= get(figno,'children');                  % Children of figure: 'Axes', i.e. subplots
    for k=1:length(figchild)
        if strcmpi( get(figchild(k),'Tag'), axtag )   % Find axes with correct tag 
            axchild=get(figchild(k),'children');      % Children of axes: Lines
            mp=[];
            for m=1:length(axchild)                   % Find lines with correct tag
                if strcmpi(get(axchild(m),'Tag'), linetag ) 
                    mp=[mp m];
                end
            end
            plines= axchild(mp);
            Npl = length(plines);
            if isempty(n), n= 1:Npl; end
            
            onoff= {'off' 'on'};    
            for m=n
                if m<=Npl
                    set(plines(m), 'Visible', onoff{on+1});  % Turn line on/off
                end
            end
        end
    end
end