function [sample,wfm,par]= LoadDatafile(measdata)
% function [sample,wfm,par]= LoadDatafile(measdata)
%
% Load Microheart raw data 
%

% Lars Hoff, Jan 2007. Extracted from 'PlotMicroheart'

mask = sprintf('%s*#%04d%s', measdata.AP, measdata.recording, measdata.systemid);
matmask = sprintf('%s.%s', mask, 'mat');
trcmask = sprintf('%s.%s', mask, 'trc');

matfile=dir(matmask);
trcfile=dir(trcmask);
matfileexist = prod(size(matfile))==1;
trcfileexist = prod(size(trcfile))==1;

if not(trcfileexist) && not(matfileexist)
    error ('No source file found')
    cd(olddir);
    return

elseif not(trcfileexist) || (matfileexist && not(measdata.reload))   % mat-file found
    fprintf('\nLoading mat-file %s ... ', matfile.name);
    load (matfile.name)
    if not(exist('par','var')), par=[]; end
    fprintf('Ready');

else
    fprintf('\nLoading trc-file %s ... ', trcfile.name);     
    [sample,wfm,par]=InterpretTRC(trcfile.name);        
    [pathstr,matfile,ext] = fileparts(trcfile.name);
    fprintf('Saving mat-file %s ... ', matfile);
    %save (matfile, 'sample', 'wfm', 'par');
    fprintf('Ready');

end
return

%--- Find interval ---
function timelimits = FindInterval(tlim,fs);
  tx  = 10; % Extra time span to load, to avoid filter transients
  tmin= max([ min(tlim)-tx 0]);
  tmax= max(tlim)+tx;

  timelimits.t0 = tmin;
  timelimits.dt = 1/fs;
  timelimits.n0 = tmin/timelimits.dt+1;
  timelimits.Nn = (tmax-tmin)/timelimits.dt;
return