function PlotMHTraces(curve,ECG,sample,measdata,pressure,dpdt);
% function PlotMHTraces(curve,ECG,sample,measdata,pressure,dpdt);
%
% Plot selected traces
% $Id: PlotMHTraces.m 98 2007-02-07 11:53:51Z lah $

% Lars Hoff, HVE, Nov 2004
% Completely revised Dec 2005

fprintf('\n')
fprintf('Plotting ... ')

if nargin<6,      dpdt.y= [];  end
if nargin<5,  pressure.y= [];  end
pinclude = not(isempty(pressure.y));

%=== AXIS TEXT, COLORS, LINES =============================
Nc= length(curve);
Nci= sum([curve.include]);

ytext = YaxisText(curve(1).type);
ECGcolor = [1 0.5 0];
for k=1:Nc
    curve(k).line = Linestyle(curve(k).sensor,curve(k).ax,k);
end

%=== SCALES ===============================================
Nct= Nci+1;                   % Total no. of curves
if pinclude, Nct=Nct+2; end   % Add pressure and dpdt curves
    
hgraphs  =stackplots(Nct);

axes(hgraphs(1))
hECG= PlotWaveform(ECG, 'plot' );
set(hECG, 'linestyle', '-', 'color', 'r');
ylabel('ECG')

for k=1:Nci
    set(hgraphs(k),'XTickLabel', []); % Remove labels from previous axes
    axes(hgraphs(k+1))
    PlotWaveform(curve(k), 'plot' );
    if not(strncmpi('curve(k)ax', 'length', 5))
        hold on
        plot(xlim,[0 0],'k-');
        hold off
    end   
    ylabel (YaxisText(curve(k).type));
    [alim,ylim{k}]= GetScale(curve(k).y);
    set(gca, 'ylim', ylim{k})
end

if (pinclude)
    for k=1:2   % Pressure and dpdt
        n=Nci+k;
        set(hgraphs(n),'XTickLabel', []); % Remove labels from previous axes
        axes(hgraphs(n+1))
        switch k
            case 1,
                q = pressure;                
                s = 'Pressure [mmHg]';
                tag= 'pressure';
            case 2, 
                q = dpdt;
                s = 'dp/dt [mmHg/s]';
                tag= 'dpdt';
        end
        PlotWaveform(q, 'plot', 'Tag', tag );
        ylabel (s);
        [alim,ylim{k}]= GetScale(q.y);
        %ylim{k}(1)=0;  % No negative pressure scale

        if diff(ylim{k})==0, ylim{k}= [0 1]; end
        set(gca, 'ylim', ylim{k})
        set(gca, 'Tag', tag)
        hold on
        ax=axis;
        plot( ax(1:2), zeros(1,2), 'k:', 'Tag', 'zeroref')
        hold off
    end
end
for k=1:Nct
    axes(hgraphs(k))
    set(gca, 'xlim', measdata.interval)
    ax=axis;
    if k==1
        graphtitle('ECG');
        titletext= sprintf( '%s. Recording %d%s', measdata.AP, measdata.recording, measdata.systemid);
        title(titletext);
        t0=min(measdata.interval)/(24*60*60);
        t1=datestr(datenum(sample.time)+t0, 'HH:MM:SS');
        text ( ax(1), ax(4), sprintf(' %s  %s', t1, sample.date), 'Verticalalignment', 'Top')
    elseif k<=Nci+1
        graphtitle(curve(k-1).name);
    end
    %RemoveLastYtick(gca);
end    
xlabel('Time [s]')

%--- Finish ---
hold off
fprintf('Ready ')
return

%=== INTERNAL FUNCTIONS ===================================
   
%--- Y-axis label ---
function ytext= YaxisText(type);
  switch lower(type(1:4))
      case {'acce','filt'},  ytext= 'Acceleration [m/s^2]';
      case 'velo',           ytext= 'Velocity [m/s]';
      case 'posi',           ytext= 'Position [m]';
      otherwise, error('Unknown motion parameter'), return
  end
return
        
%--- Line style and color ---
function line = Linestyle(sensor,ax,k);
  linecolors = {[0 0 0.7], [0.7 0 0 ] [0 0.7 0] };
  linestyles = { '--', '-' };
  if not(sensor=='0')
      line.style= linestyles(sensor-'A'+1);
      line.color= linecolors(k);
  else
      line.style= '';
      line.color= '';
  end
return
            
%--- Y-axis scales ---
function [alim,ylim]= GetScale(y)
  amax= max( max(y) );
  amin= min([min(y) 0]);
  alim= [amin amax];
  ylim= [1.1*amin 1.1*amax];  
return

%--- Graph titles --
function graphtitle(name);
    ax=axis;
    text( ax(2), ax(4), sprintf('%s ',name), ...
        'HorizontalAlignment', 'Right', ...
        'VerticalAlignment',    'Top' )
return

%--- Remove overlapping tick labels ---
function RemoveLastYtick(ax);
  tc=get(gca,'YTickLabel');
  tc(end,:)=' ';
  set(gca,'yticklabel',tc);
return
