function [sample,wfm,scaled]=SaveMicroheart(src)
% function [sample,wfm,scaled]=SaveMicroheart
%
% Calculate and plot results of Microheart measurement

% Lars Hoff, HVE, Nov 2004
%
% Completely rewritten Dec 2005.

%--- Measurement file organization constants  ---
axisorder = [1 2 3 ];    % xyz-axes mapped to sensor channels
Nch       = 3;           % No. of channels per sensor
ch= [ axisorder axisorder+Nch];
mt= [1 2 2+ch];

%--- Find and load raw data file ---
[sample,wfm,par]=InterpretTRC(src, 1);

%--- Build parameter structure ---
wfmpar= wfm;
wfmpar = rmfield(wfmpar,'trace');
wfmpar.ch    = ch;
wfmpar.sensor= sample.sensor;
wfmpar.t0    = 0;

%=== SCALE TRACES AND INTEGRATE ===================================
scaled_new= Trace2Acc(wfm.trace,wfmpar);
N=length(scaled_new.Vdd.y);

scaled.fs          = wfm.samplerate;
scaled.t           = [0:N-1]'/scaled.fs;
scaled.bias        = scaled_new.bias;
scaled.sensitivity = scaled_new.sensitivity;
scaled.Na          = scaled_new.Na;
scaled.excluded    = scaled_new.excluded;
scaled.Vdd         = scaled_new.Vdd.y;
scaled.ECG         = scaled_new.ECG.y;
scaled.a           = scaled_new.a.y;

%--- Save results ---
fprintf('\n')
[pathstr,name,ext,versn]=fileparts(sample.filename);
matfile = sprintf('%s.mat', name);
fprintf('Saving to %s', matfile  )
save(matfile , 'sample','wfm','scaled');

%--- Clean up and finish ---
fprintf('\n--- Finished --- \n')
return
